@@ -639,7 +639,21 @@ try:
 
     def setGeneralParameters(self,paramList,rec_id):
       group="general"
-      help1="""Integer representation of the bits to be considered bad when decoding the bad pixel mask pixel values."""
+      help1="""Integer representation of the bits to be considered bad when decoding the bad pixel mask pixel values.
+                    Most frequent codes relevant for the user:
+                    0: good pixel, 
+                    8: pick-up noise, 
+                    16: cosmic-ray removed, 
+                    32: cosmic-ray unremoved, 
+                    128: calibration file defect, 
+                    256: hot pixel, 
+                    512: dark pixel, 
+                    4096: A/D converted saturation, 
+                    32768: non linear pixel, 
+                    1048576: extrapolated flux in NIR, 
+                    4194304: Interpolated flux during extraction."""
+      
+      
       paramList.append(RecipeParameter(rec_id,displayName="decode-bp",group=group,description=help1))
       help2="""pre-overscan correction.0: no correction1: mean overscan correction2: mean prescan correction3: (mean pre+mean overscan)/2 correction."""
       paramList.append(RecipeParameter(rec_id,displayName="pre-overscan-corr",group=group,description=help2))
