@@ -55,7 +55,7 @@
 #include <xsh_qc_definition.h>
 #include <xsh_error.h>
 #include <xsh_msg.h>
-
+#include <xsh_ksigma_clip.h>
 #include <cpl.h>
 #include <string.h>
 
@@ -1186,6 +1186,79 @@ xsh_image_flag_bptype_with_crox(cpl_image* ima)
 
 }
 
+cpl_error_code
+xsh_count_crh(xsh_pre* pre, xsh_instrument* instr,const int datancom)
+{
+    int* pqual=NULL;
+    int size;
+    int bp_code_sat=0;
+    int ncrh=0;
+    int i=0;
+
+    float ncrh_avg=0;
+    XSH_ASSURE_NOT_NULL_MSG(pre, "Null input pre frame");
+    XSH_ASSURE_NOT_NULL_MSG(instr, "Null input pre frame");
+    size=pre->nx*pre->ny;
+
+
+    check(pqual=cpl_image_get_data_int(pre->qual));
+    for(i=0;i<size;i++) {
+        if(
+            (QFLAG_COSMIC_RAY_REMOVED   & pqual[i]) > 0 ||
+            (QFLAG_COSMIC_RAY_UNREMOVED & pqual[i]) > 0
+            )
+        {
+          (ncrh)++;
+        }
+    }
+    xsh_msg("ncrh=%d",ncrh);
+    xsh_pfits_set_qc_ncrh(pre->data_header,ncrh);
+    xsh_msg("datancom=%d",datancom);
+    ncrh_avg=ncrh/datancom;
+    xsh_msg("ncrh=%f",ncrh_avg);
+    xsh_pfits_set_qc_ncrh_mean(pre->data_header,ncrh_avg);
+
+    cleanup:
+     return cpl_error_get_code();
+}
+
+
+cpl_error_code
+xsh_count_satpix(xsh_pre* pre, xsh_instrument* instr,const int datancom)
+{
+    int* pqual=NULL;
+    int size;
+    int bp_code_sat=0;
+    int nsat=0;
+    int i=0;
+
+    float nsat_avg=0;
+    XSH_ASSURE_NOT_NULL_MSG(pre, "Null input pre frame");
+    XSH_ASSURE_NOT_NULL_MSG(instr, "Null input pre frame");
+    size=pre->nx*pre->ny;
+    bp_code_sat=QFLAG_ADC_SATURATION;
+
+    if(xsh_instrument_get_arm(instr) == XSH_ARM_NIR) {
+        bp_code_sat=QFLAG_SATURATED_DATA;
+    }
+
+    check(pqual=cpl_image_get_data_int(pre->qual));
+    for(i=0;i<size;i++) {
+        if( (bp_code_sat & pqual[i]) > 0 ) {
+          (nsat)++;
+        }
+    }
+    xsh_msg("nsat=%d",nsat);
+    xsh_pfits_set_nsat(pre->data_header,nsat);
+    xsh_msg("datancom=%d",datancom);
+    nsat_avg=nsat/datancom;
+    xsh_msg("nsat=%f",nsat_avg);
+    xsh_pfits_set_frac_sat(pre->data_header,nsat_avg);
+
+    cleanup:
+     return cpl_error_get_code();
+}
+
 cpl_error_code
 xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,const double cor_val, int flag, int* nsat)
 {
