@@ -1751,8 +1751,8 @@ xsh_compute_fpn_mbias(cpl_frameset* raws,
  if ( xsh_instrument_get_arm(instrument) != XSH_ARM_NIR){
     nraws=cpl_frameset_get_size(raws);
     if(nraws > 1) {
-       frm1=cpl_frameset_get_first(raws);
-       frm2=cpl_frameset_get_next(raws);
+       frm1=cpl_frameset_get_frame(raws,0);
+       frm2=cpl_frameset_get_frame(raws,1);
        ima1=cpl_image_load(cpl_frame_get_filename(frm1),CPL_TYPE_FLOAT,0,0);
        ima2=cpl_image_load(cpl_frame_get_filename(frm2),CPL_TYPE_FLOAT,0,0);
 
@@ -2066,6 +2066,10 @@ xsh_flat_create_normalized_master2(cpl_imagelist * flats,
   int starty=0;
   int endy=0;
   double tolerance=1.e-5;
+
+  cpl_mask* mask;
+  int nflagged=0;
+
   ni = cpl_imagelist_get_size(flats);
 
   /* evaluate median on many windows distributed all over orders of flats */
@@ -2094,7 +2098,7 @@ xsh_flat_create_normalized_master2(cpl_imagelist * flats,
     /* normalize flats by master flat previously computed */
     flat_mflat = cpl_image_duplicate(flat);
     cpl_image_divide(flat_mflat, mflat);
-
+    mask = cpl_image_get_bpm(flat_mflat);
     k = 0;
     for (ord = 0; ord < nord; ord++) {
       //absord = ord + ord_min;
@@ -2130,10 +2134,10 @@ xsh_flat_create_normalized_master2(cpl_imagelist * flats,
         check(lly=xsh_min_int(lly,ury));
 
         check(pvec_flux[k]=0);
-
-        check(
-            pvec_flux[k]=cpl_image_get_median_window(flat_mflat,llx,lly,urx,ury));
-
+        nflagged=cpl_mask_count_window(mask,llx,lly,urx,ury);
+        if(nflagged < (urx-llx+1)*(ury-lly+1) ) {
+           check(pvec_flux[k]=cpl_image_get_median_window(flat_mflat,llx,lly,urx,ury));
+        }
         k++;
       }
 
