@@ -745,6 +745,10 @@ set_qc_parameters( cpl_propertylist *tilt_header,
   check( xsh_pfits_set_qc( tilt_header, &n, QC_WAVECAL_FOUNDLINE,
                            instrument));
   check( xsh_pfits_set_qc( tilt_header, &specres_med, QC_RESOLMED, instrument));
+  if(isnan(specres_stdev)) {
+      /* dummy value to allow saving of product */
+      specres_stdev = -999;
+  }
   check( xsh_pfits_set_qc( tilt_header, &specres_stdev, QC_RESOLRMS, instrument));
 
 
