@@ -749,9 +749,9 @@ cleanup:
  */
 /*-------------------------------------------------------------------------- */
 void
-xsh_pfits_set_qc_ncrh_mean (cpl_propertylist * plist, int value)
+xsh_pfits_set_qc_ncrh_mean (cpl_propertylist * plist, const double value)
 {
-  check_msg (cpl_propertylist_update_int (plist, XSH_QC_CRH_NUMBER_MEAN, value),
+  check_msg (cpl_propertylist_update_float (plist, XSH_QC_CRH_NUMBER_MEAN, value),
 	     "Error writing keyword '%s'", XSH_QC_CRH_NUMBER_MEAN);
   cpl_propertylist_set_comment(plist, XSH_QC_CRH_NUMBER_MEAN,XSH_QC_CRH_NUMBER_MEAN_C);
 
@@ -768,7 +768,7 @@ cleanup:
 void
 xsh_pfits_set_qc_crrate (cpl_propertylist * plist, double value)
 {
-  check_msg (cpl_propertylist_update_double (plist, XSH_QC_CRH_RATE, value),
+  check_msg (cpl_propertylist_update_float (plist, XSH_QC_CRH_RATE, value),
 	     "Error writing keyword '%s'", XSH_QC_CRH_RATE);
   cpl_propertylist_set_comment(plist,XSH_QC_CRH_RATE,XSH_QC_CRH_RATE_C);
 
