@@ -184,7 +184,7 @@ static void
 add_qc_crh (xsh_pre* pre, int nbcrh, int nframes)
 {
   double qc_crrate = 0.0;
-  int nbcr_avg ;		/**< Average of cosmics per frame */
+  float nbcr_avg ;		/**< Average of cosmics per frame */
   XSH_ASSURE_NOT_NULL(pre);
   XSH_ASSURE_NOT_ILLEGAL(pre->pszx >0. && pre->pszy > 0); 
   XSH_ASSURE_NOT_ILLEGAL(pre->exptime > 0); 
