@@ -54,7 +54,7 @@
 #include <xsh_badpixelmap.h>
 #include <xsh_parameters.h>
 #include <xsh_utils_wrappers.h>
-
+#include <xsh_qc_handling.h>
 /*-----------------------------------------------------------------------------
   Functions prototypes
  -----------------------------------------------------------------------------*/
@@ -69,50 +69,6 @@
 
 
 
-/** 
- * Calculates and set the QC parameters relevant for Cosmic Rays.
- * 
- * @param pre Pointer to XSH_PRE Structure
- * @param nbcrh Total umber of cosmics found
- * @param nframes Number of frames used to remove cosmics
- */
-static void add_qc_crh (xsh_pre* pre, int nbcrh, int nframes)
-{
-  double qc_crrate = 0.0;
-  int nbcr_avg ;		/**< Average of cosmics per frame */
-
-  XSH_ASSURE_NOT_NULL(pre);
-  XSH_ASSURE_NOT_ILLEGAL(pre->pszx >0. && pre->pszy > 0); 
-  XSH_ASSURE_NOT_ILLEGAL(pre->exptime > 0); 
-  /*
-    QC.CRRATE = avg_nb_of_crh_per_frame/(exposure_time*size_of_detector_in_cm2)
-    Nb of Cosmics per cm2 per second.
-    The whole size of the image in cm2 is given by pszx and pszy. These
-    values are in MICRONS.
-  */
-  xsh_msg_dbg_medium( "add_qc_crh - Exptime = %f", pre->exptime ) ;
-  qc_crrate =
-    (double) nbcrh / (((double) nframes) * (pre->exptime * 
-    (pre->pszx / 10000.0) * (pre->pszy /10000.0) * pre->nx * pre->ny)) ;
-  nbcr_avg = nbcrh/nframes ;
-
-  /*
-    Now set QC KW
-  */
-  check( xsh_pfits_set_qc_crrate( pre->data_header,qc_crrate) ) ;
-  check( xsh_pfits_set_qc_ncrh( pre->data_header,nbcrh) ) ;
-  check( xsh_pfits_set_qc_ncrh_mean( pre->data_header,nbcr_avg) ) ;
-  /* Same thing for the qual header */
-  check( xsh_pfits_set_qc_crrate( pre->qual_header,qc_crrate) ) ;
-  check( xsh_pfits_set_qc_ncrh( pre->qual_header,nbcrh) ) ;
-  check( xsh_pfits_set_qc_ncrh_mean( pre->qual_header,nbcr_avg) ) ;
-  cleanup:
-    return ;
-}
-
-
-
-
 
 cpl_frame * xsh_abs_remove_crh_single( cpl_frame *sci_frame,
                                    xsh_instrument * instrument,
@@ -545,7 +501,7 @@ cpl_frame * xsh_remove_crh_single(cpl_frame * in_sci_frame,
 
   res_name = xsh_stringcat_any(res_tag, ".fits", (void*)NULL);
   xsh_msg_dbg_high( "Saving Result Frame '%s'", res_name);
-  check( add_qc_crh( sci_pre, nb_crh, 1) );
+  check( xsh_add_qc_crh( sci_pre, nb_crh, 1) );
   check( res_frame = xsh_pre_save( sci_pre, res_name, res_tag,0 ) );
   check( cpl_frame_set_tag( res_frame, res_tag ) );
   XSH_FREE( res_name);
