@@ -1466,7 +1466,7 @@ xsh_subtract_sky_single (cpl_frame *sci_frame,
 
 /*****************************************************************************/
 /*****************************************************************************/
-static inline int xsh_bspline_eval_all(const double x, gsl_vector *B,
+static int xsh_bspline_eval_all(const double x, gsl_vector *B,
     size_t *idx, gsl_bspline_workspace *w, size_t *start_i) {
   if (B->size != w->k) {
     GSL_ERROR("B vector not of length k", GSL_EBADLEN);
