@@ -40,7 +40,7 @@
 #include <xsh_error.h>
 #include <xsh_drl_check.h>
 #include <xsh_pfits.h>
-
+#include <xsh_hdrl_functions.h>
 /*
 static int 
 xsh_frame_has_same_nod_pos(cpl_frame* ref, cpl_frame* cmp)
@@ -129,7 +129,7 @@ xsh_stare_params_bin_scale(cpl_frameset* raws,
   int binx=0;
   int biny=0;
 
-  check(frame=cpl_frameset_get_first(raws));
+  check(frame=cpl_frameset_get_frame(raws,0));
   check(name=cpl_frame_get_filename(frame));
   check(plist=cpl_propertylist_load(name,0));
   check(binx=xsh_pfits_get_binx(plist));
@@ -230,7 +230,7 @@ cpl_frameset* xsh_nod_group_by_reloff( cpl_frameset *ord_set,xsh_instrument *ins
 
   cpl_frameset *result = NULL;
   cpl_frameset *rmcrh_set = NULL;
-  cpl_frame *frame = NULL;
+  const cpl_frame *frame = NULL;
   cpl_propertylist *header = NULL;
 
   const char* nod_name = NULL;
@@ -252,7 +252,9 @@ cpl_frameset* xsh_nod_group_by_reloff( cpl_frameset *ord_set,xsh_instrument *ins
 
   check( result=cpl_frameset_new());
 
-  check( frame = cpl_frameset_get_first( ord_set));
+  cpl_frameset_iterator* it = cpl_frameset_iterator_new(ord_set);
+  frame = cpl_frameset_iterator_get(it);
+
   check( nod_name = cpl_frame_get_filename( frame));  
   check( header = cpl_propertylist_load( nod_name, 0));
 
@@ -299,7 +301,9 @@ cpl_frameset* xsh_nod_group_by_reloff( cpl_frameset *ord_set,xsh_instrument *ins
     check( rmcrh_set = cpl_frameset_new());
     cpl_frameset_insert( rmcrh_set, cpl_frame_duplicate( frame));
 
-    check( frame = cpl_frameset_get_next( ord_set));
+    cpl_frameset_iterator_advance(it, 1);
+    frame = cpl_frameset_iterator_get_const(it);
+
     /* finds frame with same nod position to the current one and store them in the same frameset */
     while( frame != NULL){
       check( nod_name = cpl_frame_get_filename( frame));
@@ -314,7 +318,10 @@ cpl_frameset* xsh_nod_group_by_reloff( cpl_frameset *ord_set,xsh_instrument *ins
       else{
         break;
       }
-      check( frame = cpl_frameset_get_next( ord_set));
+
+      cpl_frameset_iterator_advance(it, 1);
+      frame = cpl_frameset_iterator_get_const(it);
+
     }
 
     /* Combine frames with same nod position. This to improve statistics and also remove cosmic ray hits */
@@ -335,6 +342,7 @@ cpl_frameset* xsh_nod_group_by_reloff( cpl_frameset *ord_set,xsh_instrument *ins
   }
 
   cleanup:
+    cpl_frameset_iterator_delete(it);
     if ( cpl_error_get_code() != CPL_ERROR_NONE){
       xsh_free_propertylist( &header);
       xsh_free_frameset( &rmcrh_set);
@@ -386,7 +394,8 @@ cpl_frameset* xsh_nod_group_by_reloff2( cpl_frameset *ord_set,xsh_instrument *in
 
   check( result=cpl_frameset_new());
 
-  check( frame = cpl_frameset_get_first( ord_set));
+  check( frame = cpl_frameset_get_frame( ord_set,0));
+
   check( nod_name = cpl_frame_get_filename( frame));
   check( header = cpl_propertylist_load( nod_name, 0));
 
@@ -1143,7 +1152,7 @@ xsh_scired_get_proper_maps(cpl_frameset* raws, cpl_frameset* calib,
     cpl_frame* ref_frame=NULL;
     int recipe_use_model=FALSE;
     if (xsh_mode_is_physmod(calib,instrument)){
-       ref_frame=cpl_frameset_get_first(raws);
+       ref_frame=cpl_frameset_get_frame(raws,0);
      }
      else{
        ref_frame = master_flat;
@@ -1244,7 +1253,7 @@ xsh_scired_slit_nod_get_calibs(cpl_frameset* raws,
   }
 
   if ( recipe_use_model){
-    ref_frame=cpl_frameset_get_first(raws);
+    ref_frame=cpl_frameset_get_frame(raws,0);
   }
   else{
     ref_frame = *master_flat;
